import os
import pandas as pd


def get_df(file_name):
    dataset_path = os.path.join(os.path.dirname(__file__), 'data' + os.sep + 'csv', file_name + '.csv')
    return pd.read_csv(dataset_path)


# Function to parse time series data and keep the quarters (Q1, Q2, Q3, Q4)
def parse_quarter(time_series):
    # If fractional years are present, assume quarterly data
    if any(isinstance(x, float) and x % 1 != 0 for x in time_series):
        # Convert fractional year to quarterly data
        years = [int(x) for x in time_series]
        quarters = [(int((x - int(x)) * 4) + 1) for x in time_series]
        
        # Create the string with quarters: 'YYYY-QX'
        parsed_dates = [f'{year}-Q{quarter}' for year, quarter in zip(years, quarters)]
        
        return parsed_dates  # Return the list of 'YYYY-QX' formatted strings

    # Else assume yearly data and return as 'YYYY-Q1' (for simplicity, just assume Q1)
    else:
        return [f'{int(x)}-Q1' for x in time_series]


# Function to parse time series data and extract month information from fractional year
def parse_month(time_series):
    months = []
    
    for year in time_series:
        year_int = int(year)  # Extract the year (integer part)
        month_frac = (year - year_int) * 12  # Fractional part converted to months (0.0-1.0 -> 0-11 months)
        month_int = round(month_frac) + 1  # Month in 1-12 range
        
        # Create a string in the format 'YYYY-MM'
        months.append(f'{year_int}-{month_int:02d}')
    
    return months